==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/ZoneListView.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _get() { return _get = "undefined" != typeof Reflect && Reflect.get ? Reflect.get.bind() : function (e, t, r) { var p = _superPropBase(e, t); if (p) { var n = Object.getOwnPropertyDescriptor(p, t); return n.get ? n.get.call(arguments.length < 3 ? e : r) : n.value; } }, _get.apply(null, arguments); }
function _superPropBase(t, o) { for (; !{}.hasOwnProperty.call(t, o) && null !== (t = _getPrototypeOf(t));); return t; }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * Copyright 2021 Tridium, Inc. All Rights Reserved.
 */

/* eslint-env browser */

/* global niagara */

/**
 * API Status: **Private**
 * @module nmodule/vykonPro/rc/ux/ZoneListView
 */
define(['baja!', 'bajaux/mixin/subscriberMixIn', 'bajaux/spandrel', 'jquery', 'underscore', 'nmodule/webEditors/rc/fe/baja/util/DepthSubscriber', 'nmodule/webEditors/rc/wb/profile/profileUtils', 'nmodule/bajaui/rc/util/pxUtils', 'nmodule/webEditors/rc/wb/table/Table', 'nmodule/webEditors/rc/wb/table/model/TableModel', 'nmodule/webEditors/rc/wb/table/model/columns/PropertyColumn', 'nmodule/bajaui/rc/model/UxModelSupport', 'log!uxMedia', 'lex!vykonPro', 'css!nmodule/vykonPro/rc/vykonPro'], function (baja, subscriberMixIn, spandrel, $, _, DepthSubscriber, profileUtils, pxUtils, Table, TableModel, PropertyColumn, UxModelSupport, log, lexs) {
  'use strict';

  var logSevere = log.severe.bind(log);
  var _lexs = _slicedToArray(lexs, 1),
    vykonLexicon = _lexs[0],
    widgetDefaults = function widgetDefaults() {
      return {
        properties: {
          showTitle: true,
          hyperlink: baja.Ord.make('slot:'),
          sortAscending: false
        }
      };
    };

  /**
   * @class
   * @extends {module:bajaux/Table}
   */
  var HyperlinkTable = /*#__PURE__*/function (_Table) {
    function HyperlinkTable() {
      _classCallCheck(this, HyperlinkTable);
      return _callSuper(this, HyperlinkTable, arguments);
    }
    _inherits(HyperlinkTable, _Table);
    return _createClass(HyperlinkTable, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        var _this = this;
        dom.on('click', 'tr', function (e) {
          var tableModel = _this.getModel();
          var rowIndex = $(e.currentTarget).index();
          var ord = tableModel.getRows()[rowIndex].getSubject().get('hlink');
          niagara.env.hyperlink(ord)["catch"](logSevere);
        });
        return _get(_getPrototypeOf(HyperlinkTable.prototype), "doInitialize", this).call(this, dom);
      }
    }]);
  }(Table);
  /**
   * @class
   * @alias module:nmodule/vykonPro/rc/ZoneListView
   * @extends {module:bajaux/Widget}
   */
  return /*#__PURE__*/function (_spandrel) {
    function ZoneListView(params) {
      var _this2;
      _classCallCheck(this, ZoneListView);
      _this2 = _callSuper(this, ZoneListView, [{
        params: params,
        defaults: widgetDefaults()
      }]);
      UxModelSupport(_this2);
      subscriberMixIn(_this2);
      return _this2;
    }
    _inherits(ZoneListView, _spandrel);
    return _createClass(ZoneListView, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        var _this3 = this;
        this.$subscriber = new DepthSubscriber(3);
        var eventHandler = function eventHandler() {
          return _this3.rerender();
        };
        //underscorejs.com
        this.getSubscriber().attach('changed', _.throttle(eventHandler, 5000));
        return _get(_getPrototypeOf(ZoneListView.prototype), "doInitialize", this).call(this, dom);
      }
    }]);
  }(spandrel(function (model, _ref) {
    var properties = _ref.properties,
      rootElement = _ref.rootElement;
    var hyperlink = properties.hyperlink,
      showTitle = properties.showTitle,
      sortAscending = properties.sortAscending;
    var zoneListExt = model.getValue();
    if (!zoneListExt) {
      return '<div/>';
    }
    var idColumn = new PropertyColumn('zoneId', {
      displayName: vykonLexicon.get('zoneListView.zoneId')
    });
    var valueColumn = new PropertyColumn('value', {
      displayName: vykonLexicon.get('zoneListView.value')
    });
    var hyperlinkColumn = new PropertyColumn('hlink', 'hlink');
    hyperlinkColumn.setUnseen(true);
    var baseOrd = profileUtils.getCurrentOrd().relativizeToSession();
    var zoneInfoSlots = zoneListExt.getSlots().dynamic().is('vykonPro:ZoneInfo').toArray();
    return Promise.all(zoneInfoSlots.map(function (slot) {
      var zoneInfo = zoneListExt.get(slot);
      return zoneInfo.loadSlots().then(function () {
        var linkOrd = baja.Ord.make({
          base: baseOrd,
          child: zoneInfo.get('ord').normalize()
        });
        var hlinkOrd = baja.Ord.make({
          base: linkOrd,
          child: hyperlink
        }).toUri();
        return baja.$('baja:Component', {
          zoneId: zoneInfo.get('zoneId'),
          value: zoneInfo.get('out').getValueDisplay(),
          hlink: hlinkOrd
        });
      });
    })).then(function (rows) {
      if (sortAscending === true) {
        rows.sort(function (a, b) {
          return a.get('zoneId') < b.get('zoneId') ? 1 : -1;
        });
      } else {
        rows.sort(function (a, b) {
          return a.get('zoneId') > b.get('zoneId') ? 1 : -1;
        });
      }
      var tableModel = new TableModel({
        columns: [idColumn, valueColumn, hyperlinkColumn],
        rows: rows
      });
      var div = document.createElement('div');
      div.classList.add('ux-ZoneListView');

      // hard code density for now
      var tableDensity = 'large';
      if (showTitle === true) {
        var textSpan = document.createElement('p');
        textSpan.innerText = zoneListExt.getDisplayName() + ' - Out Of Range Zones';
        textSpan.style.textAlign = 'center';
        textSpan.style.fontWeight = 'bold';
        return [{
          dom: div,
          kids: [{
            dom: textSpan
          }, {
            dom: '<div></div>',
            type: HyperlinkTable,
            value: tableModel,
            properties: {
              density: tableDensity
            }
          }]
        }];
      } else {
        return [{
          dom: '<div></div>',
          type: HyperlinkTable,
          value: tableModel,
          properties: {
            density: tableDensity
          }
        }];
      }
    });
  }));
});

==> Tridium_EMEA_N4_Supervisor-4.14.2.12.zip: rc/ZoneListView.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
function _get() { return _get = "undefined" != typeof Reflect && Reflect.get ? Reflect.get.bind() : function (e, t, r) { var p = _superPropBase(e, t); if (p) { var n = Object.getOwnPropertyDescriptor(p, t); return n.get ? n.get.call(arguments.length < 3 ? e : r) : n.value; } }, _get.apply(null, arguments); }
function _superPropBase(t, o) { for (; !{}.hasOwnProperty.call(t, o) && null !== (t = _getPrototypeOf(t));); return t; }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * Copyright 2021 Tridium, Inc. All Rights Reserved.
 */

/* eslint-env browser */

/* global niagara */

/**
 * API Status: **Private**
 * @module nmodule/vykonPro/rc/ux/ZoneListView
 */
define(['baja!', 'bajaux/mixin/subscriberMixIn', 'bajaux/spandrel', 'jquery', 'underscore', 'nmodule/webEditors/rc/fe/baja/util/DepthSubscriber', 'nmodule/webEditors/rc/wb/profile/profileUtils', 'nmodule/bajaui/rc/util/pxUtils', 'nmodule/webEditors/rc/wb/table/Table', 'nmodule/webEditors/rc/wb/table/model/TableModel', 'nmodule/webEditors/rc/wb/table/model/columns/PropertyColumn', 'nmodule/bajaui/rc/model/UxModelSupport', 'log!uxMedia', 'lex!vykonPro', 'css!nmodule/vykonPro/rc/vykonPro'], function (baja, subscriberMixIn, spandrel, $, _, DepthSubscriber, profileUtils, pxUtils, Table, TableModel, PropertyColumn, UxModelSupport, log, lexs) {
  'use strict';

  var logSevere = log.severe.bind(log);
  var _lexs = _slicedToArray(lexs, 1),
    vykonLexicon = _lexs[0],
    widgetDefaults = function widgetDefaults() {
      return {
        properties: {
          showTitle: true,
          hyperlink: baja.Ord.make('slot:'),
          sortAscending: false
        }
      };
    };

  /**
   * @class
   * @extends {module:bajaux/Table}
   */
  var HyperlinkTable = /*#__PURE__*/function (_Table) {
    function HyperlinkTable() {
      _classCallCheck(this, HyperlinkTable);
      return _callSuper(this, HyperlinkTable, arguments);
    }
    _inherits(HyperlinkTable, _Table);
    return _createClass(HyperlinkTable, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        var _this = this;
        dom.on('click', 'tr', function (e) {
          var tableModel = _this.getModel();
          var rowIndex = $(e.currentTarget).index();
          var ord = tableModel.getRows()[rowIndex].getSubject().get('hlink');
          niagara.env.hyperlink(ord)["catch"](logSevere);
        });
        return _superPropGet(HyperlinkTable, "doInitialize", this, 3)([dom]);
      }
    }]);
  }(Table);
  /**
   * @class
   * @alias module:nmodule/vykonPro/rc/ZoneListView
   * @extends {module:bajaux/Widget}
   */
  return /*#__PURE__*/function (_spandrel) {
    function ZoneListView(params) {
      var _this2;
      _classCallCheck(this, ZoneListView);
      _this2 = _callSuper(this, ZoneListView, [{
        params: params,
        defaults: widgetDefaults()
      }]);
      UxModelSupport(_this2);
      subscriberMixIn(_this2);
      return _this2;
    }
    _inherits(ZoneListView, _spandrel);
    return _createClass(ZoneListView, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        var _this3 = this;
        this.$subscriber = new DepthSubscriber(3);
        var eventHandler = function eventHandler() {
          return _this3.rerender();
        };
        //underscorejs.com
        this.getSubscriber().attach('changed', _.throttle(eventHandler, 5000));
        return _superPropGet(ZoneListView, "doInitialize", this, 3)([dom]);
      }
    }]);
  }(spandrel(function (model, _ref) {
    var properties = _ref.properties,
      rootElement = _ref.rootElement;
    var hyperlink = properties.hyperlink,
      showTitle = properties.showTitle,
      sortAscending = properties.sortAscending;
    var zoneListExt = model.getValue();
    if (!zoneListExt) {
      return '<div/>';
    }
    var idColumn = new PropertyColumn('zoneId', {
      displayName: vykonLexicon.get('zoneListView.zoneId')
    });
    var valueColumn = new PropertyColumn('value', {
      displayName: vykonLexicon.get('zoneListView.value')
    });
    var hyperlinkColumn = new PropertyColumn('hlink', 'hlink');
    hyperlinkColumn.setUnseen(true);
    var baseOrd = profileUtils.getCurrentOrd().relativizeToSession();
    var zoneInfoSlots = zoneListExt.getSlots().dynamic().is('vykonPro:ZoneInfo').toArray();
    return Promise.all(zoneInfoSlots.map(function (slot) {
      var zoneInfo = zoneListExt.get(slot);
      return zoneInfo.loadSlots().then(function () {
        var linkOrd = baja.Ord.make({
          base: baseOrd,
          child: zoneInfo.get('ord').normalize()
        });
        var hlinkOrd = baja.Ord.make({
          base: linkOrd,
          child: hyperlink
        }).toUri();
        return baja.$('baja:Component', {
          zoneId: zoneInfo.get('zoneId'),
          value: zoneInfo.get('out').getValueDisplay(),
          hlink: hlinkOrd
        });
      });
    })).then(function (rows) {
      if (sortAscending === true) {
        rows.sort(function (a, b) {
          return a.get('zoneId') < b.get('zoneId') ? 1 : -1;
        });
      } else {
        rows.sort(function (a, b) {
          return a.get('zoneId') > b.get('zoneId') ? 1 : -1;
        });
      }
      var tableModel = new TableModel({
        columns: [idColumn, valueColumn, hyperlinkColumn],
        rows: rows
      });
      var div = document.createElement('div');
      div.classList.add('ux-ZoneListView');

      // hard code density for now
      var tableDensity = 'large';
      if (showTitle === true) {
        var textSpan = document.createElement('p');
        textSpan.innerText = zoneListExt.getDisplayName() + ' - Out Of Range Zones';
        textSpan.style.textAlign = 'center';
        textSpan.style.fontWeight = 'bold';
        return [{
          dom: div,
          kids: [{
            dom: textSpan
          }, {
            dom: '<div></div>',
            type: HyperlinkTable,
            value: tableModel,
            properties: {
              density: tableDensity
            }
          }]
        }];
      } else {
        return [{
          dom: '<div></div>',
          type: HyperlinkTable,
          value: tableModel,
          properties: {
            density: tableDensity
          }
        }];
      }
    });
  }));
});
